/* Generated automatically by the program `genoutput'
   from the machine description file `md'.  */

#define IN_TARGET_CODE 1
#include "config.h"
#include "system.h"
#include "coretypes.h"
#include "backend.h"
#include "predict.h"
#include "tree.h"
#include "rtl.h"
#include "flags.h"
#include "alias.h"
#include "varasm.h"
#include "stor-layout.h"
#include "calls.h"
#include "insn-config.h"
#include "expmed.h"
#include "dojump.h"
#include "explow.h"
#include "memmodel.h"
#include "emit-rtl.h"
#include "stmt.h"
#include "expr.h"
#include "insn-codes.h"
#include "tm_p.h"
#include "regs.h"
#include "conditions.h"
#include "insn-attr.h"

#include "recog.h"

#include "diagnostic-core.h"
#include "output.h"
#include "target.h"
#include "tm-constrs.h"

static const char * const output_17[] = {
  "addk\t%0,%z1,%2",
  "addik\t%0,%z1,%2",
  "addik\t%0,%z1,%2",
};

static const char * const output_18[] = {
  "addlik\t%0,%2",
};

static const char * const output_19[] = {
  "addlk\t%0,%1,%2",
  "addlik\t%0,%1,%2 #N10",
};

static const char * const output_20[] = {
  "add\t%L0,%L1,%L2\n\taddc\t%M0,%M1,%M2",
  "addi\t%L0,%L1,%j2\n\taddic\t%M0,%M1,%h2",
};

static const char * const output_21[] = {
  "rsubk\t%0,%2,%z1",
  "addik\t%0,%z1,-%2",
};

static const char *
output_22 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 713 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[2] = gen_rtx_REG (SImode, MB_ABI_ASM_TEMP_REGNUM);
    return "mfs\t%2,rpc\n\twic\t%2,r0";
  }
}

static const char * const output_23[] = {
  "addlik\t%0,-%2",
};

static const char * const output_24[] = {
  "rsubl\t%0,%2,%1",
  "addlik\t%0,%z1,-%2",
  "addlik\t%0,%z1,-%2",
};

static const char * const output_26[] = {
  "mul\t%0,%1,%2",
  "muli\t%0,%1,%2",
  "muli\t%0,%1,%2",
};

static const char * const output_42[] = {
  "andli\t%0,%2",
};

static const char * const output_43[] = {
  "andl\t%0,%1,%2",
  "andli\t%0,%1,%2 #andl2",
  "andli\t%0,%1,%2 #andl3",
};

static const char * const output_44[] = {
  "and\t%0,%1,%2",
  "andi\t%0,%1,%2 #and1",
  "andi\t%0,%1,%2 #and2",
  "andi\t%0,%1,%2 #and3",
};

static const char * const output_45[] = {
  "orli\t%0,%2",
};

static const char * const output_46[] = {
  "orl\t%0,%1,%2",
  "orli\t%0,%1,%2 #andl1",
};

static const char * const output_47[] = {
  "or\t%0,%1,%2",
  "ori\t%0,%1,%2",
  "ori\t%0,%1,%2",
  "ori\t%0,%1,%2",
};

static const char * const output_48[] = {
  "xorli\t%0,%2",
};

static const char * const output_49[] = {
  "xorl\t%0,%1,%2",
  "xorli\t%0,%1,%2 #andl1",
};

static const char * const output_50[] = {
  "xor\t%0,%1,%2",
  "xori\t%0,%1,%2",
  "xori\t%0,%1,%2",
};

static const char * const output_51[] = {
  "andi\t%0,%1,0xffff",
  "lhu%i1\t%0,%1",
  "lhu%i1\t%0,%1",
};

static const char * const output_52[] = {
  "andi\t%0,%1,0x00ff",
  "lbu%i1\t%0,%1",
  "lbu%i1\t%0,%1",
};

static const char * const output_53[] = {
  "andi\t%0,%1,0x00ff",
  "lbu%i1\t%0,%1",
  "lbu%i1\t%0,%1",
};

static const char *
output_60 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1262 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    switch (which_alternative)
    {
      case 0:
        return "sextl32\t%0,%1";
      case 1:
      case 2:
        {
          output_asm_insn ("lw%i1\t%0,%1", operands);
          return "sextl32\t%0,%0";
        }
    } 
  }
}

static const char *
output_61 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1283 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{ 
     if (which_alternative == 0)
       output_asm_insn ("addk\t%L0,r0,%1", operands);
     else
       output_asm_insn ("lw%i1\t%L0,%1", operands);

     output_asm_insn ("add\t%M0,%L0,%L0", operands);
     output_asm_insn ("addc\t%M0,r0,r0", operands);
     output_asm_insn ("beqi\t%M0,.+8", operands);
     return "addi\t%M0,r0,0xffffffff";
  }
}

static const char * const output_62[] = {
  "mfs\t%0,%1  #mfs",
  "addlk\t%0,%1,r0 #add movdi",
  "mts\t%0,%1  #mts",
};

static const char * const output_63[] = {
  "addlk\t%0,r0,r0\t",
  "addlik\t%0,r0,%1\t #N1 %X1",
  "addlik\t%0,r0,%1\t #N2 %X1",
};

static const char *
output_64 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1377 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{ 
     gcc_unreachable ();
  }
}

static const char *
output_65 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1388 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    switch (which_alternative)
    {
      case 0:
        return "addlk\t%0,%1,r0";
     case 1:
     case 2:
        if (GET_CODE (operands[1]) == CONST_INT &&
	    (INTVAL (operands[1]) > (long long)549755813887 || INTVAL (operands[1]) < (long long)-549755813888))
	  return "addlik\t%0,r0,%h1\n\tbsllli\t%0,%0,32\n\taddlik\t%0,%0,%j1 #li => la";
        else
	  return "addlik\t%0,r0,%1";
     case 3:
     case 4:
       return "ll%i1\t%0,%1";
     case 5:
     case 6:
       return "sl%i0\t%z1,%0";
     }
   }
}

static const char *
output_66 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1416 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{ 
    switch (which_alternative)
    {
      case 0:
        return "addlk\t%0,%1,r0";
     case 1:
     case 2:
        if (GET_CODE (operands[1]) == CONST_INT && 
	    (INTVAL (operands[1]) > (long long)549755813887 || INTVAL (operands[1]) < (long long)-549755813888))
          {
            operands[2] = gen_rtx_REG (DImode, MB_ABI_ASM_TEMP_REGNUM);
            output_asm_insn ("addlik\t%0,r0,%h1", operands);
            output_asm_insn ("addlik\t%2,r0,32", operands);
            output_asm_insn ("addlik\t%2,%2,-1", operands);
            output_asm_insn ("beaneid\t%2,.-8", operands);
            output_asm_insn ("addlk\t%0,%0,%0", operands);
            return "addlik\t%0,%0,%j1 #li => la";
          }
        else	
	  return "addlik\t%0,r0,%1";
     case 3:
     case 4:
       return "ll%i1\t%0,%1";
     case 5:
     case 6:
       return "sl%i0\t%z1,%0";
     }
   }
}

static const char *
output_67 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1454 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{ 
    switch (which_alternative)
    {
      case 0:
        return "addk\t%0,%1\n\taddk\t%D0,%d1";
      case 1:
	return "addik\t%M0,r0,%h1\n\taddik\t%L0,r0,%j1 #li => la";
      case 2:
	  return "addk\t%0,r0,r0\n\taddk\t%D0,r0,r0";
      case 3:
      case 4:
        if (reg_mentioned_p (operands[0], operands[1]))
          return "lwi\t%D0,%o1\n\tlwi\t%0,%1";
	else
	  return "lwi\t%0,%1\n\tlwi\t%D0,%o1";
      case 5:
      case 6:
        return "swi\t%1,%0\n\tswi\t%D1,%o0";
    }
    return "unreachable";
  }
}

static const char * const output_69[] = {
  "mfs\t%0,%1  #mfs",
  "addk\t%0,%1,r0 #add movsi",
  "mts\t%0,%1  #mts",
};

static const char * const output_70[] = {
  "addk\t%0,r0,r0",
  "addik\t%0,r0,%1\t# %X1",
  "addik\t%0,r0,%1\t# %X1",
};

static const char *
output_71 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1561 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{ 
     gcc_unreachable ();
  }
}

static const char * const output_72[] = {
  "addk\t%0,%1,r0",
  "addik\t%0,r0,%1\t# %X1",
  "addik\t%0,%a1",
  "lw%i1\t%0,%1",
  "lw%i1\t%0,%1",
  "sw%i0\t%z1,%0",
  "sw%i0\t%z1,%0",
};

static const char * const output_73[] = {
  "addik\t%0,r0,%1\t# %X1",
  "addk\t%0,%1,r0",
  "lhu%i1\t%0,%1",
  "lhu%i1\t%0,%1",
  "sh%i0\t%z1,%0",
  "sh%i0\t%z1,%0",
};

static const char * const output_74[] = {
  "addk\t%0,r0,%z1",
  "addik\t%0,r0,%1\t# %X1",
  "addk\t%0,%1,r0",
  "lbu%i1\t%0,%1",
  "lbu%i1\t%0,%1",
  "sb%i0\t%z1,%0",
  "sb%i0\t%z1,%0",
};

static const char * const output_75[] = {
  "lwr\t%0,%y1,r0",
  "swr\t%1,%y0,r0",
};

static const char * const output_76[] = {
  "addk\t%0,r0,r0",
  "addk\t%0,%1,r0",
  "lw%i1\t%0,%1",
  "addik\t%0,r0,%F1",
  "lw%i1\t%0,%1",
  "sw%i0\t%z1,%0",
  "sw%i0\t%z1,%0",
};

static const char *
output_77 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1779 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    switch (which_alternative)
    {
      case 0:
	return "addlk\t%0,%1,r0";
      case 1:
	return "addlk\t%0,r0,r0";
      case 2:
      case 4:
          return "ll%i1\t%0,%1";
      case 3:
      {
	return "addlik\t%0,r0,%j1 \n\tbsllli\t%0,%0,32\n\taddlik\t%0,%0,%h1 #Xfer Lo";
      }
      case 5:
	return "sl%i0\t%1,%0";
    }
    gcc_unreachable ();
  }
}

static const char *
output_78 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1806 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    switch (which_alternative)
    {
      case 0:
	return "addlk\t%0,%1,r0";
      case 1:
	return "addlk\t%0,r0,r0";
      case 2:
      case 4:
          return "ll%i1\t%0,%1";
      case 3:
      {
	operands[2] = gen_rtx_REG (DImode, MB_ABI_ASM_TEMP_REGNUM);
	output_asm_insn ("addlik\t%0,r0,%h1", operands);
	output_asm_insn ("addlik\t%2,r0,32", operands);
	output_asm_insn ("addlik\t%2,%2,-1", operands);
	output_asm_insn ("beaneid\t%2,.-8", operands);
	output_asm_insn ("addlk\t%0,%0,%0", operands);
	return "addlik\t%0,%0,%j1 #li => la";
      }
      case 5:
	return "sl%i0\t%1,%0";
    }
    gcc_unreachable ();
  }
}

static const char *
output_79 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1839 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    switch (which_alternative)
    {
      case 0:
	return "addk\t%0,r0,r0\n\taddk\t%D0,r0,r0";
      case 1:
      case 3:
	if (reg_mentioned_p (operands[0], operands[1]))
          return "lwi\t%D0,%o1\n\tlwi\t%0,%1";
        else
	  return "lwi\t%0,%1\n\tlwi\t%D0,%o1";
      case 2:
      {
	return "addik\t%0,r0,%h1 \n\taddik\t%D0,r0,%j1 #Xfer Lo";
      }
      case 4:
	return "swi\t%1,%0\n\tswi\t%D1,%o0";
    }
    gcc_unreachable ();
  }
}

static const char * const output_81[] = {
  "bslli\t%0,%1,%2",
  "bsll\t%0,%1,%2",
};

static const char * const output_82[] = {
  "bsllli\t%0,%1,%2",
  "bslll\t%0,%1,%2",
};

static const char *
output_83 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1982 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (DImode, MB_ABI_ASM_TEMP_REGNUM);

    output_asm_insn ("orli\t%3,r0,%2", operands);
    if (REGNO (operands[0]) != REGNO (operands[1]))
        output_asm_insn ("addlk\t%0,%1,r0", operands);

    output_asm_insn ("addlik\t%3,%3,-1", operands);
    output_asm_insn ("beaneid\t%3,.-8", operands);
    return "addlk\t%0,%0,%0";
  }
}

static const char *
output_84 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2003 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (DImode, MB_ABI_ASM_TEMP_REGNUM);
    output_asm_insn ("andli\t%3,%2,31", operands);
    if (REGNO (operands[0]) != REGNO (operands[1])) 
      output_asm_insn ("addlk\t%0,r0,%1", operands);
    /* Exit the loop if zero shift. */
    output_asm_insn ("beaeqid\t%3,.+24", operands);
    /* Emit the loop.  */
    output_asm_insn ("addlk\t%0,%0,r0", operands);
    output_asm_insn ("addlik\t%3,%3,-1", operands);
    output_asm_insn ("beaneid\t%3,.-8", operands);
    return "addlk\t%0,%0,%0";
  }
}

static const char *
output_85 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2029 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[2] = gen_int_mode (1 << INTVAL (operands[2]), SImode);
    return "muli\t%0,%1,%2";
  }
}

static const char *
output_86 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2044 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[2] = gen_int_mode (1 << INTVAL (operands[2]), SImode);
    return "muli\t%0,%1,%2";
  }
}

static const char *
output_87 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2059 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (SImode, MB_ABI_ASM_TEMP_REGNUM);

    output_asm_insn ("ori\t%3,r0,%2", operands);
    if (REGNO (operands[0]) != REGNO (operands[1]))
        output_asm_insn ("addk\t%0,%1,r0", operands);

    output_asm_insn ("addik\t%3,%3,-1", operands);
    output_asm_insn ("bneid\t%3,.-4", operands);
    return "addk\t%0,%0,%0";
  }
}

static const char *
output_88 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2080 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    int i, nshift;
    
    nshift = INTVAL (operands[2]);
    operands[3] = gen_int_mode (0xFFFFFFFF << nshift, SImode);

    /* We do one extra shift so that the first bit (carry) coming into the MSB
       will be masked out */
    output_asm_insn ("src\t%0,%1", operands);
    for (i = 0; i < (32 - nshift); i++)
       output_asm_insn ("src\t%0,%0", operands);

    return "andi\t%0,%0,%3";
  }
}

static const char *
output_89 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2104 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    int i;
    int nshift = INTVAL (operands[2]);
    if (REGNO (operands[0]) != REGNO (operands[1]))
      output_asm_insn ("addk\t%0,r0,%1", operands);
    output_asm_insn ("addk\t%0,%1,%1", operands);
    for (i = 0; i < (nshift - 2); i++)
      output_asm_insn ("addk\t%0,%0,%0", operands);
    return "addk\t%0,%0,%0";
  }
}

static const char *
output_90 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2124 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (SImode, MB_ABI_ASM_TEMP_REGNUM);
    output_asm_insn ("andi\t%3,%2,31", operands);
    if (REGNO (operands[0]) != REGNO (operands[1])) 
      output_asm_insn ("addk\t%0,r0,%1", operands);
    /* Exit the loop if zero shift. */
    output_asm_insn ("beqid\t%3,.+20", operands);
    /* Emit the loop.  */
    output_asm_insn ("addk\t%0,%0,r0", operands);
    output_asm_insn ("addik\t%3,%3,-1", operands);
    output_asm_insn ("bneid\t%3,.-4", operands);
    return "addk\t%0,%0,%0";
  }
}

static const char * const output_91[] = {
  "bslrai\t%0,%1,%2",
  "bslra\t%0,%1,%2",
};

static const char *
output_92 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2192 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (DImode, MB_ABI_ASM_TEMP_REGNUM);

    output_asm_insn ("orli\t%3,r0,%2", operands);
    if (REGNO (operands[0]) != REGNO (operands[1]))
        output_asm_insn ("addlk\t%0,%1,r0", operands);

    output_asm_insn ("addlik\t%3,%3,-1", operands);
    output_asm_insn ("beaneid\t%3,.-8", operands);
    return "srla\t%0,%0";
  }
}

static const char *
output_93 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2213 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (DImode, MB_ABI_ASM_TEMP_REGNUM);
    output_asm_insn ("andli\t%3,%2,31", operands);
    if (REGNO (operands[0]) != REGNO (operands[1])) 
      output_asm_insn ("addlk\t%0,r0,%1", operands);
    /* Exit the loop if zero shift. */
    output_asm_insn ("beaeqid\t%3,.+24", operands);
    /* Emit the loop.  */
    output_asm_insn ("addlk\t%0,%0,r0", operands);
    output_asm_insn ("addlik\t%3,%3,-1", operands);
    output_asm_insn ("beaneid\t%3,.-8", operands);
    return "srla\t%0,%0";
  }
}

static const char * const output_95[] = {
  "bsrai\t%0,%1,%2",
  "bsra\t%0,%1,%2",
};

static const char *
output_96 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2278 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (SImode, MB_ABI_ASM_TEMP_REGNUM);

    output_asm_insn ("ori\t%3,r0,%2", operands);
    if (REGNO (operands[0]) != REGNO (operands[1]))
        output_asm_insn ("addk\t%0,%1,r0", operands);

    output_asm_insn ("addik\t%3,%3,-1", operands);
    output_asm_insn ("bneid\t%3,.-4", operands);
    return "sra\t%0,%0";
  }
}

static const char *
output_97 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2299 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    int i;
    int nshift = INTVAL (operands[2]);
    if (REGNO (operands[0]) != REGNO (operands[1]))
      output_asm_insn ("addk\t%0,r0,%1", operands);
    output_asm_insn ("sra\t%0,%1", operands);
    for (i = 0; i < (nshift - 2); i++)
      output_asm_insn ("sra\t%0,%0", operands);
    return "sra\t%0,%0";
  }
}

static const char *
output_98 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2319 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (SImode, MB_ABI_ASM_TEMP_REGNUM);
    output_asm_insn ("andi\t%3,%2,31", operands);
    if (REGNO (operands[0]) != REGNO (operands[1])) 
      output_asm_insn ("addk\t%0,r0,%1", operands);
    /* Exit the loop if zero shift. */
    output_asm_insn ("beqid\t%3,.+20", operands);
    /* Emit the loop.  */
    output_asm_insn ("addk\t%0,%0,r0", operands);
    output_asm_insn ("addik\t%3,%3,-1", operands);
    output_asm_insn ("bneid\t%3,.-4", operands);
    return "sra\t%0,%0";
  }
}

static const char * const output_99[] = {
  "bslrli\t%0,%1,%2",
  "bslrl\t%0,%1,%2",
};

static const char *
output_100 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2386 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (DImode, MB_ABI_ASM_TEMP_REGNUM);

    output_asm_insn ("orli\t%3,r0,%2", operands);
    if (REGNO (operands[0]) != REGNO (operands[1]))
        output_asm_insn ("addlk\t%0,%1,r0", operands);

    output_asm_insn ("addlik\t%3,%3,-1", operands);
    output_asm_insn ("beaneid\t%3,.-8", operands);
    return "srll\t%0,%0";
  }
}

static const char *
output_101 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2407 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (DImode, MB_ABI_ASM_TEMP_REGNUM);
    output_asm_insn ("andli\t%3,%2,31", operands);
    if (REGNO (operands[0]) != REGNO (operands[1]))
      output_asm_insn ("addlk\t%0,r0,%1", operands);
    /* Exit the loop if zero shift. */
    output_asm_insn ("beaeqid\t%3,.+24", operands);
    /* Emit the loop.  */
    output_asm_insn ("addlk\t%0,%0,r0", operands);
    output_asm_insn ("addlik\t%3,%3,-1", operands);
    output_asm_insn ("beaneid\t%3,.-8", operands);
    return "srll\t%0,%0";
  }
}

static const char * const output_103[] = {
  "bsrli\t%0,%1,%2",
  "bsrl\t%0,%1,%2",
};

static const char *
output_104 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2472 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (SImode, MB_ABI_ASM_TEMP_REGNUM);

    output_asm_insn ("ori\t%3,r0,%2", operands);
    if (REGNO (operands[0]) != REGNO (operands[1]))
        output_asm_insn ("addk\t%0,%1,r0", operands);

    output_asm_insn ("addik\t%3,%3,-1", operands);
    output_asm_insn ("bneid\t%3,.-4", operands);
    return "srl\t%0,%0";
  }
}

static const char *
output_105 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2493 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    int i;
    int nshift = INTVAL (operands[2]);
    if (REGNO (operands[0]) != REGNO (operands[1]))
      output_asm_insn ("addk\t%0,r0,%1", operands);
    output_asm_insn ("srl\t%0,%1", operands);
    for (i = 0; i < (nshift - 2); i++)
      output_asm_insn ("srl\t%0,%0", operands);
    return "srl\t%0,%0";
  }
}

static const char *
output_106 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2513 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[3] = gen_rtx_REG (SImode, MB_ABI_ASM_TEMP_REGNUM);
    output_asm_insn ("andi\t%3,%2,31", operands);
    if (REGNO (operands[0]) != REGNO (operands[1])) 
      output_asm_insn ("addk\t%0,r0,%1", operands);
    /* Exit the loop if zero shift. */
    output_asm_insn ("beqid\t%3,.+20", operands);
    /* Emit the loop.  */
    output_asm_insn ("addk\t%0,%0,r0", operands);
    output_asm_insn ("addik\t%3,%3,-1", operands);
    output_asm_insn ("bneid\t%3,.-4", operands);
    return "srl\t%0,%0";
  }
}

static const char *
output_113 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2683 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    if (operands[3] == pc_rtx) 
      return "bea%C0i%?\t%z1,%2";
    else 
      return "bea%N0i%?\t%z1,%3";
  }
}

static const char *
output_114 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2703 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    if (operands[3] == pc_rtx) 
      return "beal%C0i%?\t%z1,%2";
    else 
      return "beal%N0i%?\t%z1,%3";
  }
}

static const char *
output_115 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2723 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    if (operands[3] == pc_rtx) 
      return "b%C0i%?\t%z1,%2";
    else 
      return "b%N0i%?\t%z1,%3";
  }
}

static const char *
output_116 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2744 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[4] = gen_rtx_REG (SImode, MB_ABI_ASM_TEMP_REGNUM);
    enum rtx_code code = GET_CODE (operands[0]);

    if (code == GT || code == LE)
      {
        output_asm_insn ("cmp\tr18,%z1,%z2", operands);
        code = swap_condition (code);
      }
    else if (code == GTU || code == LEU)
      {
        output_asm_insn ("cmpu\tr18,%z1,%z2", operands);
        code = swap_condition (code);
      }
    else if (code == GE || code == LT)
      {
        output_asm_insn ("cmp\tr18,%z2,%z1", operands);
      }
    else if (code == GEU || code == LTU)
      {
        output_asm_insn ("cmpu\tr18,%z2,%z1", operands);
      }

    operands[0] = gen_rtx_fmt_ee (signed_condition (code), SImode, operands[4], const0_rtx);
    return "bea%C0i%?\tr18,%3";
  }
}

static const char *
output_117 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2785 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[4] = gen_rtx_REG (DImode, MB_ABI_ASM_TEMP_REGNUM);
    enum rtx_code code = GET_CODE (operands[0]);

    if (code == GT || code == LE)
      {
        output_asm_insn ("cmpl\tr18,%z1,%z2", operands);
        code = swap_condition (code);
      }
    else if (code == GTU || code == LEU)
      {
        output_asm_insn ("cmplu\tr18,%z1,%z2", operands);
        code = swap_condition (code);
      }
    else if (code == GE || code == LT)
      {
        output_asm_insn ("cmpl\tr18,%z2,%z1", operands);
      }
    else if (code == GEU || code == LTU)
      {
        output_asm_insn ("cmplu\tr18,%z2,%z1", operands);
      }

    operands[0] = gen_rtx_fmt_ee (signed_condition (code), DImode, operands[4], const0_rtx);
    return "beal%C0i%?\tr18,%3";
  }
}

static const char *
output_118 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2826 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    operands[4] = gen_rtx_REG (SImode, MB_ABI_ASM_TEMP_REGNUM);
    enum rtx_code code = GET_CODE (operands[0]);

    if (code == GT || code == LE)
      {
        output_asm_insn ("cmp\tr18,%z1,%z2", operands);
        code = swap_condition (code);
      }
    else if (code == GTU || code == LEU)
      {
        output_asm_insn ("cmpu\tr18,%z1,%z2", operands);
        code = swap_condition (code);
      }
    else if (code == GE || code == LT)
      {
        output_asm_insn ("cmp\tr18,%z2,%z1", operands);
      }
    else if (code == GEU || code == LTU)
      {
        output_asm_insn ("cmpu\tr18,%z2,%z1", operands);
      }

    operands[0] = gen_rtx_fmt_ee (signed_condition (code), SImode, operands[4], const0_rtx);
    return "b%C0i%?\tr18,%3";
  }
}

static const char *
output_119 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2905 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    if (GET_CODE (operands[0]) == REG)
        return "brea%?\t%0";
    else	
        return "breai%?\t%l0";
  }
}

static const char *
output_120 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2919 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    if (GET_CODE (operands[0]) == REG)
        return "br%?\t%0";
    else	
        return "bri%?\t%l0";
  }
}

static const char *
output_124 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3014 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    output_asm_insn ("addk\t%0,%0,r20",operands);
    return "bra%?\t%0";
}
}

static const char *
output_125 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3039 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    output_asm_insn ("addlk\t%0,%0,r20",operands);
    return "bra%?\t%0";
}
}

static const char *
output_126 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3143 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    if (microblaze_is_break_handler ())
        return "rtbd\tr16, 8\n\t%#";
    else if (microblaze_is_interrupt_variant ())
        return "rtid\tr14, 0\n\t%#";
    else
        return "rtsd\tr15, 8\n\t%#";
  }
}

static const char *
output_127 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3143 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    if (microblaze_is_break_handler ())
        return "rtbd\tr16, 8\n\t%#";
    else if (microblaze_is_interrupt_variant ())
        return "rtid\tr14, 0\n\t%#";
    else
        return "rtsd\tr15, 8\n\t%#";
  }
}

static const char *
output_128 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3162 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    if (microblaze_is_break_handler ())
        return "rtbd\tr16,8\n\t%#";
    else if (microblaze_is_interrupt_variant ())
        return "rtid\tr14,0 \n\t%#";
    else
        return "rtsd\tr15,8 \n\t%#";
  }
}

static const char *
output_129 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3162 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    if (microblaze_is_break_handler ())
        return "rtbd\tr16,8\n\t%#";
    else if (microblaze_is_interrupt_variant ())
        return "rtid\tr14,0 \n\t%#";
    else
        return "rtsd\tr15,8 \n\t%#";
  }
}

static const char *
output_131 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3251 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    register rtx target2 = gen_rtx_REG (Pmode, 
			      GP_REG_FIRST + MB_ABI_SUB_RETURN_ADDR_REGNUM);
    gen_rtx_CLOBBER (VOIDmode, target2);
    return "brealid\tr15,%0\n\t%#";
  }
}

static const char *
output_132 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3267 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    rtx target2
      = gen_rtx_REG (Pmode, GP_REG_FIRST + MB_ABI_SUB_RETURN_ADDR_REGNUM);
    gen_rtx_CLOBBER (VOIDmode, target2);
    return "brlid\tr15,%0\n\t%#";
  }
}

static const char *
output_133 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3282 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    register rtx target = operands[0];
    register rtx target2 = gen_rtx_REG (Pmode,
			      GP_REG_FIRST + MB_ABI_SUB_RETURN_ADDR_REGNUM);
    if (GET_CODE (target) == SYMBOL_REF) {
        if (microblaze_break_function_p (SYMBOL_REF_DECL (target))) {
            gen_rtx_CLOBBER (VOIDmode, target2);
            return "breaki\tr16,%0\n\t%#";
        }
        else {
            gen_rtx_CLOBBER (VOIDmode, target2);
            return "brealid\tr15,%0\n\t%#";
        }
    } else if (GET_CODE (target) == CONST_INT)
        return "la\t%@,r0,%0\n\tbrald\tr15,%@\n\t%#";
    else if (GET_CODE (target) == REG)
        return "brald\tr15,%0\n\t%#";	
    else {
        fprintf (stderr,"Unsupported call insn\n");
        return NULL;
    }
  }
}

static const char *
output_134 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3313 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{
    rtx target = operands[0];
    rtx target2
      = gen_rtx_REG (Pmode, GP_REG_FIRST + MB_ABI_SUB_RETURN_ADDR_REGNUM);
    if (GET_CODE (target) == SYMBOL_REF) {
        if (microblaze_break_function_p (SYMBOL_REF_DECL (target))) {
            gen_rtx_CLOBBER (VOIDmode, target2);
            return "brki\tr16,%0\n\t%#";
        }
        else {
            gen_rtx_CLOBBER (VOIDmode, target2);
            return "brlid\tr15,%0\n\t%#";
        }
    } else if (GET_CODE (target) == CONST_INT)
        return "la\t%@,r0,%0\n\tbrald\tr15,%@\n\t%#";
    else if (GET_CODE (target) == REG)
        return "brald\tr15,%0\n\t%#";	
    else {
        fprintf (stderr,"Unsupported call insn\n");
        return NULL;
    }
  }
}

static const char *
output_135 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3407 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{ 
    register rtx target2=gen_rtx_REG (Pmode,GP_REG_FIRST + MB_ABI_SUB_RETURN_ADDR_REGNUM);

    gen_rtx_CLOBBER (VOIDmode,target2);
    return "brealid\tr15,%1\n\t%#";
  }
}

static const char *
output_136 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3424 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{ 
    rtx target2
      = gen_rtx_REG (Pmode,GP_REG_FIRST + MB_ABI_SUB_RETURN_ADDR_REGNUM);

    gen_rtx_CLOBBER (VOIDmode,target2);
    return "brlid\tr15,%1\n\t%#";
  }
}

static const char *
output_137 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3441 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{ 
    register rtx target = operands[1];
    register rtx target2=gen_rtx_REG (Pmode,GP_REG_FIRST + MB_ABI_SUB_RETURN_ADDR_REGNUM);

    if (GET_CODE (target) == SYMBOL_REF)
    {
      gen_rtx_CLOBBER (VOIDmode,target2);
      if (microblaze_break_function_p (SYMBOL_REF_DECL (target)))
        return "breaki\tr16,%1\n\t%#";
      else if (SYMBOL_REF_FLAGS (target) & SYMBOL_FLAG_FUNCTION)
        {
	  return "brealid\tr15,%1\n\t%#";
        }
      else
        {
	    return "bralid\tr15,%1\n\t%#";
        }
    }
    else if (GET_CODE (target) == CONST_INT)
        return "la\t%@,r0,%1\n\tbrald\tr15,%@\n\t%#";
    else if (GET_CODE (target) == REG)
        return "brald\tr15,%1\n\t%#";	
    else 
        return "Unsupported call insn\n";
  }
}

static const char *
output_138 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3476 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md"
{ 
    rtx target = operands[1];
    rtx target2
      = gen_rtx_REG (Pmode,GP_REG_FIRST + MB_ABI_SUB_RETURN_ADDR_REGNUM);

    if (GET_CODE (target) == SYMBOL_REF)
    {
      gen_rtx_CLOBBER (VOIDmode,target2);
      if (microblaze_break_function_p (SYMBOL_REF_DECL (target)))
        return "brki\tr16,%1\n\t%#";
      else if (SYMBOL_REF_FLAGS (target) & SYMBOL_FLAG_FUNCTION)
        {
	  return "brlid\tr15,%1\n\t%#";
        }
      else
        {
	    return "bralid\tr15,%1\n\t%#";
        }
    }
    else if (GET_CODE (target) == CONST_INT)
        return "la\t%@,r0,%1\n\tbrald\tr15,%@\n\t%#";
    else if (GET_CODE (target) == REG)
        return "brald\tr15,%1\n\t%#";	
    else 
        return "Unsupported call insn\n";
  }
}

static const char *
output_146 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 36 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/sync.md"
{
    output_asm_insn ("add  \t%0,r0,r0", operands);
    output_asm_insn ("lwx  \t%1,%y2,r0", operands);
    output_asm_insn ("addic\t%8,r0,0", operands);
    output_asm_insn ("bnei \t%8,.-8", operands);
    output_asm_insn ("cmp  \t%8,%1,%3", operands);
    output_asm_insn ("bnei \t%8,.+20", operands);
    output_asm_insn ("swx  \t%4,%y2,r0", operands);
    output_asm_insn ("addic\t%8,r0,0", operands);
    output_asm_insn ("bnei \t%8,.-28", operands);
    output_asm_insn ("addi \t%0,r0,1", operands);
    return "";
  }
}



static const struct insn_operand_data operand_data[] = 
{
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    reg_or_0_operand,
    "%dJ,dJ,dJ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_plus_operand,
    "d,I,i",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_plus_operand,
    "d,K",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "K",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d,d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,K,n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,I,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "%0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "K",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,K,I",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "%d,d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,I,i,M",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,K",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "%d,d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,I,M,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "%d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,K",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "%d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "d,I,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "d,R,m",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=d,d,d",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "d,R,m",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=d,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "d,R,m",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "d,R,m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=d,d,z",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "z,d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "=d,d,d",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "J,I,Mnis",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    call_insn_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=d,d,d,d,d,R,m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    move_src_operand,
    "d,I,Mnis,R,m,dJ,dJ",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=d,d,d,d,d,R,o",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "d,i,J,R,o,d,d",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "i",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=d,d,z",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "z,d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "=d,d,d",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "J,I,Mnis",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    call_insn_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=d,d,d,d,d,R,m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    move_src_operand,
    "d,I,Mnis,R,m,dJ,dJ",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=d,d,d,d,R,m",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "I,d,R,m,dJ,dJ",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=d,d,d,d,d,R,m",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "J,I,d,R,m,dJ,dJ",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    reg_or_mem_operand,
    "=r,Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    reg_or_mem_operand,
    "Q,r",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=d,d,d,d,d,R,m",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "G,d,R,F,m,d,d",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=d,d,d,d,d,m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "d,dG,m,F,T,d",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=d,d,d,d,o",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "dG,o,F,T,d",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "I",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "I,d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "I,d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_DImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "r",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    pc_or_label_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    pc_or_label_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_DImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    pc_or_label_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    pc_or_label_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    pc_or_label_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    pc_or_label_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    cmp_op,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cmp_op,
    "",
    E_DImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    call_insn_plt_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "i",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    call_insn_simple_operand,
    "ri",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "i",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    call_insn_plt_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "i",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    call_insn_operand,
    "ri",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "i",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&d",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_plus_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=&d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "I,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    arith_operand,
    "I,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    ordered_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "d",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "i",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=d",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "i",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "I",
    E_SImode,
    0,
    0,
    1,
    0
  },
};


#if GCC_VERSION >= 2007
__extension__
#endif

const struct insn_data_d insn_data[] = 
{
  /* <internal>:0 */
  {
    "*placeholder_for_nothing",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { 0 },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:441 */
  {
    "bswapsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "swapb %0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswapsi2 },
    &operand_data[1],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:451 */
  {
    "bswaphi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "swapb %0, %1\n\
   swaph %0, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswaphi2 },
    &operand_data[3],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:477 */
  {
    "addsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsf3 },
    &operand_data[5],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:487 */
  {
    "subsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsub\t%0,%2,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subsf3 },
    &operand_data[5],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:497 */
  {
    "mulsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulsf3 },
    &operand_data[5],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:507 */
  {
    "divsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fdiv\t%0,%2,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divsf3 },
    &operand_data[5],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:518 */
  {
    "sqrtsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsqrt\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtsf2 },
    &operand_data[5],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:527 */
  {
    "floatsisf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "flt\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatsisf2 },
    &operand_data[8],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:536 */
  {
    "fix_truncsfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fint\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncsfsi2 },
    &operand_data[10],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:546 */
  {
    "adddf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dadd\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddf3 },
    &operand_data[12],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:556 */
  {
    "subdf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "drsub\t%0,%2,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdf3 },
    &operand_data[12],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:566 */
  {
    "muldf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dmul\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_muldf3 },
    &operand_data[12],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:576 */
  {
    "divdf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ddiv\t%0,%2,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divdf3 },
    &operand_data[12],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:587 */
  {
    "sqrtdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dsqrt\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtdf2 },
    &operand_data[12],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:596 */
  {
    "floatdidf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dbl\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatdidf2 },
    &operand_data[15],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:605 */
  {
    "fix_truncdfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dlong\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncdfdi2 },
    &operand_data[17],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:621 */
  {
    "addsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_17 },
#else
    { 0, output_17, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsi3 },
    &operand_data[19],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:657 */
  {
    "adddi3_int",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_18 },
#else
    { 0, output_18, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3_int },
    &operand_data[22],
    3,
    3,
    0,
    1,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:669 */
  {
    "*adddi3_long",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_19 },
#else
    { 0, output_19, 0 },
#endif
    { 0 },
    &operand_data[25],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:681 */
  {
    "*adddi3_all",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_20 },
#else
    { 0, output_20, 0 },
#endif
    { 0 },
    &operand_data[28],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:697 */
  {
    "subsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_21 },
#else
    { 0, output_21, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subsi3 },
    &operand_data[31],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:709 */
  {
    "iprefetch",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_22 },
#else
    { 0, 0, output_22 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iprefetch },
    &operand_data[34],
    1,
    1,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:734 */
  {
    "subdi316imm",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_23 },
#else
    { 0, output_23, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdi316imm },
    &operand_data[35],
    3,
    3,
    0,
    1,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:746 */
  {
    "subsidi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_24 },
#else
    { 0, output_24, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subsidi3 },
    &operand_data[38],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:759 */
  {
    "subdi3_small",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsub\t%L0,%L2,%L1\n\trsubc\t%M0,%M2,%M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdi3_small },
    &operand_data[41],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:774 */
  {
    "mulsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_26 },
#else
    { 0, output_26, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulsi3 },
    &operand_data[44],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:787 */
  {
    "mulsidi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%L0,%1,%2\n\tmulh\t%M0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulsidi3 },
    &operand_data[47],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:798 */
  {
    "umulsidi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%L0,%1,%2\n\tmulhu\t%M0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulsidi3 },
    &operand_data[47],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:809 */
  {
    "usmulsidi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%L0,%1,%2\n\tmulhsu\t%M0,%2,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usmulsidi3 },
    &operand_data[47],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:820 */
  {
    "*smulsi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mulh\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[50],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:833 */
  {
    "*umulsi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mulhu\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[50],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:847 */
  {
    "*usmulsi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mulhsu\t%0,%2,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[50],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:886 */
  {
    "divsi3_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "idiv\t%0,%2,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divsi3_internal },
    &operand_data[50],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:898 */
  {
    "udivsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "idivu\t%0,%2,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_udivsi3 },
    &operand_data[50],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:952 */
  {
    "negsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubk\t%0,%1,r0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negsi2 },
    &operand_data[50],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:961 */
  {
    "negsi_long",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubk\t%0,%1,r0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negsi_long },
    &operand_data[53],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:970 */
  {
    "negdi2_long",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubl\t%0,%1,r0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negdi2_long },
    &operand_data[35],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:979 */
  {
    "negdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsub\t%L0,%L1,r0\n\trsubc\t%M0,%M1,r0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negdi2 },
    &operand_data[35],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:989 */
  {
    "one_cmplsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xori\t%0,%1,-1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplsi2 },
    &operand_data[50],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1006 */
  {
    "*microblaze.md:1006",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xorli\t%0,%1,-1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[55],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1015 */
  {
    "*microblaze.md:1015",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nor\t%M0,r0,%M1\n\tnor\t%L0,r0,%L1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[35],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1042 */
  {
    "anddi3imm16",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_42 },
#else
    { 0, output_42, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_anddi3imm16 },
    &operand_data[57],
    3,
    3,
    0,
    1,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1053 */
  {
    "anddi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_43 },
#else
    { 0, output_43, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_anddi3 },
    &operand_data[60],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1066 */
  {
    "andsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_44 },
#else
    { 0, output_44, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andsi3 },
    &operand_data[63],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1080 */
  {
    "iordi3imm16",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_45 },
#else
    { 0, output_45, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iordi3imm16 },
    &operand_data[57],
    3,
    3,
    0,
    1,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1091 */
  {
    "iordi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_46 },
#else
    { 0, output_46, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iordi3 },
    &operand_data[66],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1103 */
  {
    "iorsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_47 },
#else
    { 0, output_47, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorsi3 },
    &operand_data[69],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1117 */
  {
    "xordi3imm16",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_48 },
#else
    { 0, output_48, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xordi3imm16 },
    &operand_data[57],
    3,
    3,
    0,
    1,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1128 */
  {
    "xordi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_49 },
#else
    { 0, output_49, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xordi3 },
    &operand_data[72],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1141 */
  {
    "xorsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_50 },
#else
    { 0, output_50, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsi3 },
    &operand_data[75],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1158 */
  {
    "zero_extendhisi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_51 },
#else
    { 0, output_51, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendhisi2 },
    &operand_data[78],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1170 */
  {
    "zero_extendqihi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_52 },
#else
    { 0, output_52, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendqihi2 },
    &operand_data[80],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1182 */
  {
    "zero_extendqisi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_53 },
#else
    { 0, output_53, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendqisi2 },
    &operand_data[82],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1194 */
  {
    "zero_extendhidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "andli\t%0,%1,0xffff",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendhidi2 },
    &operand_data[84],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1203 */
  {
    "zero_extendsidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "andli\t%0,%1,0xffffffff",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendsidi2 },
    &operand_data[86],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1212 */
  {
    "zero_extendqidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "andli\t%0,%1,0x00ff",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendqidi2 },
    &operand_data[88],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1227 */
  {
    "extendqisi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sext8\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendqisi2 },
    &operand_data[90],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1236 */
  {
    "extendhisi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sext16\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendhisi2 },
    &operand_data[92],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1245 */
  {
    "extendhidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sextl16\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendhidi2 },
    &operand_data[84],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1258 */
  {
    "extendsidi2_long",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_60 },
#else
    { 0, 0, output_60 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendsidi2_long },
    &operand_data[94],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1279 */
  {
    "extendsidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_61 },
#else
    { 0, 0, output_61 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendsidi2 },
    &operand_data[94],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1345 */
  {
    "movdi_status",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_62 },
#else
    { 0, output_62, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdi_status },
    &operand_data[96],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1358 */
  {
    "*movdi_internal3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_63 },
#else
    { 0, output_63, 0 },
#endif
    { 0 },
    &operand_data[98],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1372 */
  {
    "*movdi_internal5_pltop",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_64 },
#else
    { 0, 0, output_64 },
#endif
    { 0 },
    &operand_data[100],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1384 */
  {
    "*movdi_internal2_bshift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_65 },
#else
    { 0, 0, output_65 },
#endif
    { 0 },
    &operand_data[102],
    2,
    2,
    0,
    7,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1412 */
  {
    "*movdi_internal2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_66 },
#else
    { 0, 0, output_66 },
#endif
    { 0 },
    &operand_data[102],
    2,
    2,
    0,
    7,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1450 */
  {
    "*movdi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_67 },
#else
    { 0, 0, output_67 },
#endif
    { 0 },
    &operand_data[104],
    2,
    2,
    0,
    7,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1505 */
  {
    "movdi_long_int",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addlik\t%0,r0,%h1\n\tbsllli\t%0,%0,32\n\taddlik\t%0,%0,%j1 #li => la",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdi_long_int },
    &operand_data[106],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1528 */
  {
    "movsi_status",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_69 },
#else
    { 0, output_69, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsi_status },
    &operand_data[108],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1541 */
  {
    "*movsi_internal3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_70 },
#else
    { 0, output_70, 0 },
#endif
    { 0 },
    &operand_data[110],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1556 */
  {
    "*movsi_internal5_pltop",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_71 },
#else
    { 0, 0, output_71 },
#endif
    { 0 },
    &operand_data[112],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1568 */
  {
    "*movsi_internal2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_72 },
#else
    { 0, output_72, 0 },
#endif
    { 0 },
    &operand_data[114],
    2,
    2,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1612 */
  {
    "*movhi_internal2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_73 },
#else
    { 0, output_73, 0 },
#endif
    { 0 },
    &operand_data[116],
    2,
    2,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1652 */
  {
    "*movqi_internal2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_74 },
#else
    { 0, output_74, 0 },
#endif
    { 0 },
    &operand_data[118],
    2,
    2,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1690 */
  {
    "movsi4_rev",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_75 },
#else
    { 0, output_75, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsi4_rev },
    &operand_data[120],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1723 */
  {
    "*movsf_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_76 },
#else
    { 0, output_76, 0 },
#endif
    { 0 },
    &operand_data[122],
    2,
    2,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1775 */
  {
    "*movdf_internal_64_bshift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_77 },
#else
    { 0, 0, output_77 },
#endif
    { 0 },
    &operand_data[124],
    2,
    2,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1802 */
  {
    "*movdf_internal_64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_78 },
#else
    { 0, 0, output_78 },
#endif
    { 0 },
    &operand_data[124],
    2,
    2,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1835 */
  {
    "*movdf_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_79 },
#else
    { 0, 0, output_79 },
#endif
    { 0 },
    &operand_data[126],
    2,
    2,
    0,
    5,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1911 */
  {
    "*ashlsi3_byone",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addk\t%0,%1,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[128],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1923 */
  {
    "ashlsi3_bshift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_81 },
#else
    { 0, output_81, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlsi3_bshift },
    &operand_data[131],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1964 */
  {
    "ashldi3_long",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_82 },
#else
    { 0, output_82, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashldi3_long },
    &operand_data[134],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1977 */
  {
    "ashldi3_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_83 },
#else
    { 0, 0, output_83 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashldi3_const },
    &operand_data[137],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1998 */
  {
    "ashldi3_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_84 },
#else
    { 0, 0, output_84 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashldi3_reg },
    &operand_data[41],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2023 */
  {
    "*ashlsi3_with_mul_delay",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_85 },
#else
    { 0, 0, output_85 },
#endif
    { 0 },
    &operand_data[140],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2039 */
  {
    "*ashlsi3_with_mul_nodelay",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_86 },
#else
    { 0, 0, output_86 },
#endif
    { 0 },
    &operand_data[140],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2054 */
  {
    "*ashlsi3_with_size_opt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_87 },
#else
    { 0, 0, output_87 },
#endif
    { 0 },
    &operand_data[143],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2075 */
  {
    "*ashlsi3_with_rotate",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_88 },
#else
    { 0, 0, output_88 },
#endif
    { 0 },
    &operand_data[143],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2099 */
  {
    "*ashlsi_inline",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_89 },
#else
    { 0, 0, output_89 },
#endif
    { 0 },
    &operand_data[143],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2119 */
  {
    "*ashlsi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_90 },
#else
    { 0, 0, output_90 },
#endif
    { 0 },
    &operand_data[146],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2174 */
  {
    "ashrdi3_long",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_91 },
#else
    { 0, output_91, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrdi3_long },
    &operand_data[134],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2187 */
  {
    "ashrdi3_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_92 },
#else
    { 0, 0, output_92 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrdi3_const },
    &operand_data[137],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2208 */
  {
    "ashrdi3_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_93 },
#else
    { 0, 0, output_93 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrdi3_reg },
    &operand_data[41],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2248 */
  {
    "*ashrsi3_byone",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sra\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[128],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2260 */
  {
    "*ashrsi3_bshift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_95 },
#else
    { 0, output_95, 0 },
#endif
    { 0 },
    &operand_data[131],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2273 */
  {
    "*ashrsi3_with_size_opt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_96 },
#else
    { 0, 0, output_96 },
#endif
    { 0 },
    &operand_data[143],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2294 */
  {
    "*ashrsi_inline",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_97 },
#else
    { 0, 0, output_97 },
#endif
    { 0 },
    &operand_data[143],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2314 */
  {
    "*ashrsi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_98 },
#else
    { 0, 0, output_98 },
#endif
    { 0 },
    &operand_data[146],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2368 */
  {
    "lshrdi3_long",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_99 },
#else
    { 0, output_99, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrdi3_long },
    &operand_data[134],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2381 */
  {
    "lshrdi3_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_100 },
#else
    { 0, 0, output_100 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrdi3_const },
    &operand_data[137],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2402 */
  {
    "lshrdi3_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_101 },
#else
    { 0, 0, output_101 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrdi3_reg },
    &operand_data[41],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2442 */
  {
    "*lshrsi3_byone",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srl\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[128],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2454 */
  {
    "*lshrsi3_bshift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_103 },
#else
    { 0, output_103, 0 },
#endif
    { 0 },
    &operand_data[131],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2467 */
  {
    "*lshrsi3_with_size_opt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_104 },
#else
    { 0, 0, output_104 },
#endif
    { 0 },
    &operand_data[143],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2488 */
  {
    "*lshrsi_inline",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_105 },
#else
    { 0, 0, output_105 },
#endif
    { 0 },
    &operand_data[143],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2508 */
  {
    "*lshrsi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_106 },
#else
    { 0, 0, output_106 },
#endif
    { 0 },
    &operand_data[146],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2546 */
  {
    "seq_internal_pat_long",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pcmpleq\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_seq_internal_pat_long },
    &operand_data[149],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2558 */
  {
    "sne_internal_pat_long",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pcmplne\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sne_internal_pat_long },
    &operand_data[149],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2570 */
  {
    "seq_internal_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pcmpeq\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_seq_internal_pat },
    &operand_data[50],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2582 */
  {
    "sne_internal_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pcmpne\t%0,%1,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sne_internal_pat },
    &operand_data[50],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2599 */
  {
    "cstoresf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmp.%C1\t%0,%3,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoresf4 },
    &operand_data[152],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2611 */
  {
    "cstoredf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dcmp.%C1\t%0,%3,%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoredf4 },
    &operand_data[156],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2674 */
  {
    "branch_zero_64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_113 },
#else
    { 0, 0, output_113 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_branch_zero_64 },
    &operand_data[160],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2694 */
  {
    "long_branch_zero",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_114 },
#else
    { 0, 0, output_114 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_long_branch_zero },
    &operand_data[164],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2714 */
  {
    "branch_zero",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_115 },
#else
    { 0, 0, output_115 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_branch_zero },
    &operand_data[168],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2734 */
  {
    "branch_compare64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_116 },
#else
    { 0, 0, output_116 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_branch_compare64 },
    &operand_data[172],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2775 */
  {
    "long_branch_compare",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_117 },
#else
    { 0, 0, output_117 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_long_branch_compare },
    &operand_data[176],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2816 */
  {
    "branch_compare",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_118 },
#else
    { 0, 0, output_118 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_branch_compare },
    &operand_data[172],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2901 */
  {
    "jump_64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_119 },
#else
    { 0, 0, output_119 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_jump_64 },
    &operand_data[175],
    1,
    1,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2915 */
  {
    "jump",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_120 },
#else
    { 0, 0, output_120 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_jump },
    &operand_data[175],
    1,
    1,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2944 */
  {
    "indirect_jump_internal1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bra%?\t%0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_indirect_jump_internal1 },
    &operand_data[180],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2976 */
  {
    "tablejump_internal1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bra%?\t%0 ",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tablejump_internal1 },
    &operand_data[174],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2986 */
  {
    "tablejump_internal2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bra%?\t%0 ",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tablejump_internal2 },
    &operand_data[178],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3006 */
  {
    "*microblaze.md:3006",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_124 },
#else
    { 0, 0, output_124 },
#endif
    { 0 },
    &operand_data[174],
    2,
    2,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3031 */
  {
    "*microblaze.md:3031",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_125 },
#else
    { 0, 0, output_125 },
#endif
    { 0 },
    &operand_data[178],
    2,
    2,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3140 */
  {
    "*return",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_126 },
#else
    { 0, 0, output_126 },
#endif
    { 0 },
    &operand_data[0],
    0,
    0,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3140 */
  {
    "*simple_return",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_127 },
#else
    { 0, 0, output_127 },
#endif
    { 0 },
    &operand_data[0],
    0,
    0,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3158 */
  {
    "return_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_128 },
#else
    { 0, 0, output_128 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_return_internal },
    &operand_data[181],
    1,
    1,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3158 */
  {
    "simple_return_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_129 },
#else
    { 0, 0, output_129 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_simple_return_internal },
    &operand_data[181],
    1,
    1,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3177 */
  {
    "blockage",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_blockage },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3245 */
  {
    "call_internal_plt_64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_131 },
#else
    { 0, 0, output_131 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_internal_plt_64 },
    &operand_data[182],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3261 */
  {
    "call_internal_plt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_132 },
#else
    { 0, 0, output_132 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_internal_plt },
    &operand_data[182],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3277 */
  {
    "call_internal1_64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_133 },
#else
    { 0, 0, output_133 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_internal1_64 },
    &operand_data[184],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3308 */
  {
    "call_internal1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_134 },
#else
    { 0, 0, output_134 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_internal1 },
    &operand_data[184],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3400 */
  {
    "call_value_intern_plt_64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_135 },
#else
    { 0, 0, output_135 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_value_intern_plt_64 },
    &operand_data[186],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3417 */
  {
    "call_value_intern_plt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_136 },
#else
    { 0, 0, output_136 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_value_intern_plt },
    &operand_data[186],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3435 */
  {
    "call_value_intern_64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_137 },
#else
    { 0, 0, output_137 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_value_intern_64 },
    &operand_data[191],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3470 */
  {
    "call_value_intern",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_138 },
#else
    { 0, 0, output_138 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_value_intern },
    &operand_data[191],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3537 */
  {
    "nop",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nop",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nop },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3546 */
  {
    "trap",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bri\t0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_trap },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3555 */
  {
    "set_got",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mfs\t%0,rpc\n\taddik\t%0,%0,_GLOBAL_OFFSET_TABLE_+8",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_set_got },
    &operand_data[195],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3566 */
  {
    "set_text",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mfs\t%0,rpc\n\taddik\t%0,%0,8@TXTPCREL",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_set_text },
    &operand_data[1],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3577 */
  {
    "clzsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "clz\t%0,%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzsi2 },
    &operand_data[1],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3622 */
  {
    "extv_32",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bsefi %0,%1,%2,%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extv_32 },
    &operand_data[196],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3654 */
  {
    "insv_32",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bsifi %0, %3, %1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_insv_32 },
    &operand_data[200],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/sync.md:20 */
  {
    "atomic_compare_and_swapsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_146 },
#else
    { 0, 0, output_146 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_compare_and_swapsi },
    &operand_data[204],
    8,
    9,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:642 */
  {
    "adddi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3 },
    &operand_data[213],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:725 */
  {
    "subdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdi3 },
    &operand_data[216],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:865 */
  {
    "divsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divsi3 },
    &operand_data[50],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:998 */
  {
    "one_cmpldi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmpldi2 },
    &operand_data[213],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1309 */
  {
    "movdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdi },
    &operand_data[219],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1518 */
  {
    "movsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsi },
    &operand_data[221],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1594 */
  {
    "movhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movhi },
    &operand_data[223],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1634 */
  {
    "movqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movqi },
    &operand_data[225],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1674 */
  {
    "cpymemsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cpymemsi },
    &operand_data[227],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1703 */
  {
    "movsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsf },
    &operand_data[231],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1742 */
  {
    "movdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdf },
    &operand_data[233],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1894 */
  {
    "ashlsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlsi3 },
    &operand_data[235],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:1937 */
  {
    "ashldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashldi3 },
    &operand_data[238],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2147 */
  {
    "ashrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrdi3 },
    &operand_data[238],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2231 */
  {
    "ashrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrsi3 },
    &operand_data[235],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2341 */
  {
    "lshrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrdi3 },
    &operand_data[238],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2425 */
  {
    "lshrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrsi3 },
    &operand_data[235],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2534 */
  {
    "cstoresi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoresi4 },
    &operand_data[241],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2627 */
  {
    "cbranchsi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchsi4 },
    &operand_data[245],
    4,
    4,
    0,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2640 */
  {
    "cbranchsi4_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchsi4_reg },
    &operand_data[249],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2653 */
  {
    "cbranchsf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchsf4 },
    &operand_data[253],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2668 */
  {
    "condjump",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_condjump },
    &operand_data[256],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2858 */
  {
    "cbranchdi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchdi4 },
    &operand_data[258],
    4,
    4,
    0,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2871 */
  {
    "cbranchdi4_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchdi4_reg },
    &operand_data[262],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2884 */
  {
    "cbranchdf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchdf4 },
    &operand_data[266],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2929 */
  {
    "indirect_jump",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_indirect_jump },
    &operand_data[180],
    1,
    1,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2952 */
  {
    "tablejump",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tablejump },
    &operand_data[270],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:2996 */
  {
    "tablejump_internal3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tablejump_internal3 },
    &operand_data[272],
    2,
    2,
    1,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3022 */
  {
    "tablejump_internal4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tablejump_internal4 },
    &operand_data[274],
    2,
    2,
    1,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3051 */
  {
    "prologue",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_prologue },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3060 */
  {
    "epilogue",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_epilogue },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3073 */
  {
    "allocate_stack",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_allocate_stack },
    &operand_data[276],
    2,
    2,
    1,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3100 */
  {
    "save_stack_block",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_save_stack_block },
    &operand_data[250],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3110 */
  {
    "restore_stack_block",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_restore_stack_block },
    &operand_data[250],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3128 */
  {
    "return",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_return },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3134 */
  {
    "simple_return",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_simple_return },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3190 */
  {
    "call",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call },
    &operand_data[278],
    4,
    4,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3226 */
  {
    "call_internal0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_internal0 },
    &operand_data[280],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3235 */
  {
    "call_internal_plt0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_internal_plt0 },
    &operand_data[280],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3341 */
  {
    "call_value",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_value },
    &operand_data[284],
    4,
    4,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3380 */
  {
    "call_value_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_value_internal },
    &operand_data[280],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3390 */
  {
    "call_value_intern_plt0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_value_intern_plt0 },
    &operand_data[287],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3508 */
  {
    "untyped_call",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_untyped_call },
    &operand_data[280],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3587 */
  {
    "eh_return",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_eh_return },
    &operand_data[292],
    1,
    1,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3596 */
  {
    "extvsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extvsi },
    &operand_data[293],
    4,
    4,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/microblaze/microblaze.md:3633 */
  {
    "insvsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_insvsi },
    &operand_data[200],
    4,
    4,
    0,
    1,
    0
  },
};


const char *
get_insn_name (int code)
{
  if (code == NOOP_MOVE_INSN_CODE)
    return "NOOP_MOVE";
  else
    return insn_data[code].name;
}
